==> zego_uikit_prebuilt_call-4.1.8.tar.gz: README.md <==
# Call Kit

**Call Kit** is a prebuilt feature-rich call component, which enables you to build **one-on-one and group voice/video calls** into your app with only a few lines of code.

We also support online invitation and offline invitation.

And it includes the business logic with the UI, you can add or remove features accordingly by customizing UI components.

>
>
>If you find this package helpful, please help by giving it a 👍 on pub.dev! ↗️
>
>Your support and encouragement motivate us to continue improving and maintaining this package.
>
>Thank you for recognizing our work! 👏👏
---

[![ZEGOCLOUD Video Call Feature Intro](https://res.cloudinary.com/marcomontalbano/image/upload/v1682407474/video_to_markdown/images/youtube--mEg32GyIqgI-c05b58ac6eb4c4700831b2b3070cd403.jpg)](https://www.youtube.com/embed/mEg32GyIqgI "ZEGOCLOUD Video Call Feature Intro")

## When do you need the Call Kit

- Build apps faster and easier
  - When you want to prototype 1-on-1 or group voice/video calls ASAP
  - Consider speed or efficiency as the first priority
  - Call Kit allows you to integrate in minutes
- Customize UI and features as needed
  - When you want to customize in-call features based on actual business needs
  - Less time wasted developing basic features
  - Call Kit includes the business logic along with the UI, allows you to customize features accordingly

## Features

- 1-on-1/group calls
- Call invitation/Offline call invitation
- Screen sharing
- Customizable UI styles
- Real-time sound waves display
- Device management
- Switch views during a 1-on-1 call
- Extendable menu bar
- Participant list
- Custom call ringtones

## Documentation

- [APIs](https://pub.dev/documentation/zego_uikit_prebuilt_call/latest/topics/APIs-topic.html)
- [Events](https://pub.dev/documentation/zego_uikit_prebuilt_call/latest/topics/Events-topic.html)
- [Configs](https://pub.dev/documentation/zego_uikit_prebuilt_call/latest/topics/Configs-topic.html)

>

- [Quick start](https://zegocloud.spreading.io/doc/callkit/Call%20Kit/main/Quick%20start/b26d509e)
- [Quick start with call invitation](https://zegocloud.spreading.io/doc/callkit/Call%20Kit/main/Quick%20start%20(with%20call%20invitation)/eb1d3c42)
- Calling Configs
  - [Set avatar for users](https://zegocloud.spreading.io/doc/callkit/Call%20Kit/main/Calling%20config/Set%20avatar%20for%20users/0b0379a1)
  - [Add custom components](https://zegocloud.spreading.io/doc/callkit/Call%20Kit/main/Calling%20config/Add%20custom%20components/104f3892)
  - [Configure layouts](https://zegocloud.spreading.io/doc/callkit/Call%20Kit/main/Calling%20config/Configure%20layouts/72e3cb8a)
  - [Hide the label on the user view](https://zegocloud.spreading.io/doc/callkit/Call%20Kit/main/Calling%20config/Hide%20the%20label%20on%20the%20user%20view/d05f2d97)
  - [Implement an audio-only call](https://zegocloud.spreading.io/doc/callkit/Call%20Kit/main/Calling%20config/Implement%20an%20audio-only%20call/649285b6)
  - [Customize the menu bar](https://zegocloud.spreading.io/doc/callkit/Call%20Kit/main/Calling%20config/Customize%20the%20menu%20bar/db8f439f)
  - [Set a hangup confirmation dialog](https://zegocloud.spreading.io/doc/callkit/Call%20Kit/main/Calling%20config/Set%20a%20hangup%20confirmation%20dialog/f6a7433c)
  - [Calculate call duration](https://zegocloud.spreading.io/doc/callkit/Call%20Kit/main/Calling%20config/Calculate%20call%20duration/c75ba0e1)
  - [Minimize call window](https://zegocloud.spreading.io/doc/callkit/Call%20Kit/main/Calling%20config/Minimize%20call%20window/4a12fd9e)
  - [Set video config](https://zegocloud.spreading.io/doc/callkit/Call%20Kit/main/Calling%20config/Set%20video%20config/da12304d)
- Invitation Configs
  - [Customize the ringtone](https://zegocloud.spreading.io/doc/callkit/Call%20Kit/main/Invitation%20config/Customize%20the%20ringtone/0fcda8ea)
  - [Hide the decline/cancel button](https://zegocloud.spreading.io/doc/callkit/Call%20Kit/main/Invitation%20config/Hide%20the%20decline/cancel%20button/6be662b7)
  - [Customizing Calling Background](https://zegocloud.spreading.io/doc/callkit/Call%20Kit/main/Invitation%20config/Customizing%20Calling%20Background/a8673748)
  - [Auto re-send call invitation after call timeout](https://zegocloud.spreading.io/doc/callkit/Call%20Kit/main/Invitation%20config/Auto%20re-send%20call%20invitation%20after%20call%20timeout/c8736cd7)
  - [Modify User Interface text](https://zegocloud.spreading.io/doc/callkit/Call%20Kit/main/Invitation%20config/Modify%20User%20Interface%20text/49aac7d2)
  - [Customizing the icon for the iOS CallKit UI](https://zegocloud.spreading.io/doc/callkit/Call%20Kit/main/Invitation%20config/Customizing%20the%20icon%20for%20the%20iOS%20CallKit%20UI/1dc1fc86)
  - [API for call invitation](https://zegocloud.spreading.io/doc/callkit/Call%20Kit/main/Invitation%20config/API%20for%20call%20invitation/b417a083)
  - [Callbacks for call invitation](https://zegocloud.spreading.io/doc/callkit/Call%20Kit/main/Invitation%20config/Callbacks%20for%20call%20invitation/763b69a7)
  - [FAQ](https://zegocloud.spreading.io/doc/callkit/Call%20Kit/main/Invitation%20config/FAQ/0d1a020c)
- Advance Features
  - [Screen sharing](https://zegocloud.spreading.io/doc/callkit/Call%20Kit/main/Advanced%20Features/Screen%20sharing/4fb3f574)
  - [Beauty effects](https://zegocloud.spreading.io/doc/callkit/Call%20Kit/main/Advanced%20Features/Beauty%20effects/edfb08d6)
- [Troubleshooting call invitations](https://zegocloud.spreading.io/doc/callkit/Call%20Kit/main/Troubleshooting%20call%20invitations/4981e46f)


## Migration Guides

- [Migrating from 3.x to 4.0.0](https://pub.dev/documentation/zego_uikit_prebuilt_call/latest/topics/Migration:%20from%203.x%20to%204.0-topic.html).
- [Migrating from 4.1.3 to 4.1.4](https://pub.dev/documentation/zego_uikit_prebuilt_call/latest/topics/Migration:%204.x-topic.html#414).

## More
[Sample Code](https://github.com/ZEGOCLOUD/zego_uikit_prebuilt_call_example_flutter)

<br />

[Please visit our official website for more details.](https://docs.zegocloud.com/article/14746)

==> zego_uikit_prebuilt_call-4.1.10.tar.gz: README.md <==
# Call Kit

**Call Kit** is a prebuilt feature-rich call component, which enables you to build **one-on-one and group voice/video calls** into your app with only a few lines of code.

We also support online invitation and offline invitation.

And it includes the business logic with the UI, you can add or remove features accordingly by customizing UI components.

>
>
>If you find this package helpful, please help by giving it a 👍 on pub.dev! ↗️
>
>Your support and encouragement motivate us to continue improving and maintaining this package.
>
>Thank you for recognizing our work! 👏👏
---

[![ZEGOCLOUD Video Call Feature Intro](https://res.cloudinary.com/marcomontalbano/image/upload/v1682407474/video_to_markdown/images/youtube--mEg32GyIqgI-c05b58ac6eb4c4700831b2b3070cd403.jpg)](https://www.youtube.com/embed/mEg32GyIqgI "ZEGOCLOUD Video Call Feature Intro")

## When do you need the Call Kit

- Build apps faster and easier
  - When you want to prototype 1-on-1 or group voice/video calls ASAP
  - Consider speed or efficiency as the first priority
  - Call Kit allows you to integrate in minutes
- Customize UI and features as needed
  - When you want to customize in-call features based on actual business needs
  - Less time wasted developing basic features
  - Call Kit includes the business logic along with the UI, allows you to customize features accordingly

## Features

- 1-on-1/group calls
- Call invitation/Offline call invitation
- Screen sharing
- Customizable UI styles
- Real-time sound waves display
- Device management
- Switch views during a 1-on-1 call
- Extendable menu bar
- Participant list
- Custom call ringtones

## Documentation

- [APIs](https://pub.dev/documentation/zego_uikit_prebuilt_call/latest/topics/APIs-topic.html)
- [Events](https://pub.dev/documentation/zego_uikit_prebuilt_call/latest/topics/Events-topic.html)
- [Configs](https://pub.dev/documentation/zego_uikit_prebuilt_call/latest/topics/Configs-topic.html)

> 
> 

- [Quick start](https://zegocloud.spreading.io/doc/callkit/Call%20Kit/main/Quick%20start/b26d509e)
- [Quick start with call invitation](https://zegocloud.spreading.io/doc/callkit/Call%20Kit/main/Quick%20start%20(with%20call%20invitation)/eb1d3c42)
- Calling Configs
  - [Set avatar for users](https://zegocloud.spreading.io/doc/callkit/Call%20Kit/main/Calling%20config/Set%20avatar%20for%20users/0b0379a1)
  - [Add custom components](https://zegocloud.spreading.io/doc/callkit/Call%20Kit/main/Calling%20config/Add%20custom%20components/104f3892)
  - [Configure layouts](https://zegocloud.spreading.io/doc/callkit/Call%20Kit/main/Calling%20config/Configure%20layouts/72e3cb8a)
  - [Hide the label on the user view](https://zegocloud.spreading.io/doc/callkit/Call%20Kit/main/Calling%20config/Hide%20the%20label%20on%20the%20user%20view/d05f2d97)
  - [Implement an audio-only call](https://zegocloud.spreading.io/doc/callkit/Call%20Kit/main/Calling%20config/Implement%20an%20audio-only%20call/649285b6)
  - [Customize the menu bar](https://zegocloud.spreading.io/doc/callkit/Call%20Kit/main/Calling%20config/Customize%20the%20menu%20bar/db8f439f)
  - [Set a hangup confirmation dialog](https://zegocloud.spreading.io/doc/callkit/Call%20Kit/main/Calling%20config/Set%20a%20hangup%20confirmation%20dialog/f6a7433c)
  - [Calculate call duration](https://zegocloud.spreading.io/doc/callkit/Call%20Kit/main/Calling%20config/Calculate%20call%20duration/c75ba0e1)
  - [Minimize call window](https://zegocloud.spreading.io/doc/callkit/Call%20Kit/main/Calling%20config/Minimize%20call%20window/4a12fd9e)
  - [Set video config](https://zegocloud.spreading.io/doc/callkit/Call%20Kit/main/Calling%20config/Set%20video%20config/da12304d)
- Invitation Configs
  - [Customize the ringtone](https://zegocloud.spreading.io/doc/callkit/Call%20Kit/main/Invitation%20config/Customize%20the%20ringtone/0fcda8ea)
  - [Hide the decline/cancel button](https://zegocloud.spreading.io/doc/callkit/Call%20Kit/main/Invitation%20config/Hide%20the%20decline/cancel%20button/6be662b7)
  - [Customizing Calling Background](https://zegocloud.spreading.io/doc/callkit/Call%20Kit/main/Invitation%20config/Customizing%20Calling%20Background/a8673748)
  - [Auto re-send call invitation after call timeout](https://zegocloud.spreading.io/doc/callkit/Call%20Kit/main/Invitation%20config/Auto%20re-send%20call%20invitation%20after%20call%20timeout/c8736cd7)
  - [Modify User Interface text](https://zegocloud.spreading.io/doc/callkit/Call%20Kit/main/Invitation%20config/Modify%20User%20Interface%20text/49aac7d2)
  - [Customizing the icon for the iOS CallKit UI](https://zegocloud.spreading.io/doc/callkit/Call%20Kit/main/Invitation%20config/Customizing%20the%20icon%20for%20the%20iOS%20CallKit%20UI/1dc1fc86)
  - [API for call invitation](https://zegocloud.spreading.io/doc/callkit/Call%20Kit/main/Invitation%20config/API%20for%20call%20invitation/b417a083)
  - [Callbacks for call invitation](https://zegocloud.spreading.io/doc/callkit/Call%20Kit/main/Invitation%20config/Callbacks%20for%20call%20invitation/763b69a7)
  - [FAQ](https://zegocloud.spreading.io/doc/callkit/Call%20Kit/main/Invitation%20config/FAQ/0d1a020c)
- Advance Features
  - [Screen sharing](https://zegocloud.spreading.io/doc/callkit/Call%20Kit/main/Advanced%20Features/Screen%20sharing/4fb3f574)
  - [Beauty effects](https://zegocloud.spreading.io/doc/callkit/Call%20Kit/main/Advanced%20Features/Beauty%20effects/edfb08d6)
- [Troubleshooting call invitations](https://zegocloud.spreading.io/doc/callkit/Call%20Kit/main/Troubleshooting%20call%20invitations/4981e46f)


## Migration Guides

- [Migrating from 3.x to 4.0.0](https://pub.dev/documentation/zego_uikit_prebuilt_call/latest/topics/Migration:%204.x-topic.html#400).
- [Migrating from 4.1.3 to 4.1.4](https://pub.dev/documentation/zego_uikit_prebuilt_call/latest/topics/Migration:%204.x-topic.html#414).
  
## More
[Sample Code](https://github.com/ZEGOCLOUD/zego_uikit_prebuilt_call_example_flutter)

<br />

[Please visit our official website for more details.](https://docs.zegocloud.com/article/14746)
